smartcard.pcsc.PCSCContext.PCSCContext

# ``smartcard`.`pcsc`.`PCSCContext`.`PCSCContext``

class documentation

`class PCSCContext(object):`

View In Hierarchy

Manage a singleton pcsc context handle.

Static Method | `renewContext` | Undocumented
Method | `__getattr__` | Undocumented
Method | `__init__` | Undocumented
Class Variable | `instance` | Undocumented
Class Variable | `mutex` | Undocumented
Class | `__PCSCContextSingleton` | The actual pcsc context class as a singleton.

def renewContext():

Undocumented

def __getattr__(self, name):

Undocumented

def __init__(self):

Undocumented

instance =

Undocumented

mutex =

Undocumented